refresh static method
void
refresh()
Trigger a rebuild of reactive widgets This is useful when you need to force a UI update
Implementation
static void refresh() {
// Notify all active Rx objects to rebuild
// This is a simplified implementation
// In a full implementation, this would notify all listeners
}