FlowsMaterialApp class
FlowsMaterialApp - Material app with Flows routing support
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlowsMaterialApp
Constructors
-
FlowsMaterialApp({Key? key, Widget? home, String? initialRoute, List<
FlowsPage> ? pages, ThemeData? theme, ThemeData? darkTheme, ThemeMode? themeMode, bool debugShowCheckedModeBanner = true, Map<String, Widget Function(BuildContext)> ? routes, Widget unknownRoute(BuildContext)?, Widget builder(BuildContext, Widget?)?, String? title}) -
const
Properties
- builder → Widget Function(BuildContext, Widget?)?
-
Builder for wrapping the entire app
final
- darkTheme → ThemeData?
-
Dark theme data
final
- debugShowCheckedModeBanner → bool
-
Debug banner enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → Widget?
-
The home widget
final
- initialRoute → String?
-
The initial route
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
Navigator observers
final
-
pages
→ List<
FlowsPage> ? -
All pages for the app
final
-
routes
→ Map<
String, Widget Function(BuildContext)> ? -
Custom routes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData?
-
Theme data
final
- themeMode → ThemeMode?
-
Theme mode - can be a reactive value
final
- title → String?
-
App title for accessibility
final
- unknownRoute → Widget Function(BuildContext)?
-
Unknown route handler
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlowsMaterialApp> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited