SnackbarController class
Snackbar Controller to manage snackbar
Constructors
- SnackbarController(FlowsSnackBar snackBar)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snackBar → FlowsSnackBar
-
final
Methods
-
dismiss(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isSnackbarBeingShown → bool
-
no setter
Static Methods
-
cancelAllSnackbars(
) → void -
closeCurrentSnackbar(
) → Future< void>