rx/rx library

Rx - Reactive types

Classes

Rx<T>
Base Rx class that manages all the stream logic for any Type.
RxBool
RxBool for boolean values
RxDouble
RxDouble for double values
RxInt
RxInt for integer values
RxInterface<T>
Base interface for reactive types
RxList<T>
Reactive List that notifies listeners when modified
RxMap<K, V>
A reactive Map that notifies listeners when modified
Rxn<T>
Nullable Rx class
RxnBool
RxnBool for nullable boolean values
RxnDouble
RxnDouble for nullable double values
RxnInt
RxnInt for nullable integer values
RxnList<T>
RxnList - Nullable Reactive List
RxnString
RxnString for nullable string values
RxString
RxString for string values
Worker
Worker class to manage reactive subscriptions
Workers
Workers container to manage multiple workers

Extensions

BoolExtension on bool
DoubleExtension on double
IntExtension on int
RxBoolExt on Rx<bool>
RxnBoolExt on Rx<bool?>
RxNumExt on Rx<num>
RxT on T
RxTnew on Object
New extension to avoid conflicts with dart 3 features
RxWorkerExtension on RxInterface<T>
Extension on RxInterface for easier worker usage
StringExtension on String

Functions

debounce<T>(RxInterface<T> observable, WorkerCallback<T> callback, {Duration time = const Duration(milliseconds: 500)}) Worker
Executes a callback after delay of no changes (debounce). Similar to interval but sends the last value after user stops changing it.
ever<T>(RxInterface<T> observable, WorkerCallback<T> callback, {dynamic condition, Duration? debounce}) Worker
Executes a callback every time the value of observable changes.
everAll<T>(List<RxInterface<T>> observables, WorkerCallback<T> callback, {dynamic condition}) Worker
Similar to ever, but takes a list of observables. The condition is common to all observables.
interval<T>(RxInterface<T> observable, WorkerCallback<T> callback, {Duration delay = const Duration(seconds: 1), dynamic condition}) Worker
Executes a callback after delay if the value of observable doesn't change.
once<T>(RxInterface<T> observable, WorkerCallback<T> callback, {dynamic condition}) Worker
Executes a callback the first time the value of observable changes.
workers() Workers
Create workers container

Typedefs

WorkerCallback<T> = void Function(T value)