RxDouble class

RxDouble for double values

Inheritance

Constructors

RxDouble(double initial)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toJson() → dynamic
Returns the json representation of value.
inherited
toString() String
A string representation of this object.
inherited
trigger(double v) → void
Trigger a rebuild even if the value is the same
inherited
update(double fn(double? val)) → void
Uses a callback to update value internally
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited