RxInterface<T> class abstract

Base interface for reactive types

Inheritance
Implementers
Available extensions

Constructors

RxInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
The current value of the object.
getter/setter pairoverride-getter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(WorkerCallback<T> callback, {Duration? debounce}) Worker

Available on RxInterface<T>, provided by the RxWorkerExtension extension

Execute callback every time value changes
onFirstChange(WorkerCallback<T> callback) Worker

Available on RxInterface<T>, provided by the RxWorkerExtension extension

Execute callback only once when value changes
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited