Rxn<T> class
Nullable Rx class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
T?> - Rx<
T?> - Rxn
- Available extensions
Constructors
- Rxn([T? initial])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isFalse → bool
-
Available on Rx<
bool> , provided by the RxBoolExt extensionno setter - isFalse → bool?
-
Available on Rx<
bool?> , provided by the RxnBoolExt extensionno setter - isTrue → bool
-
Available on Rx<
bool> , provided by the RxBoolExt extensionno setter - isTrue → bool?
-
Available on Rx<
bool?> , provided by the RxnBoolExt extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T?
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
decrement(
[num by = 1]) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
increment(
[num by = 1]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onChanged(
WorkerCallback< T> callback, {Duration? debounce}) → Worker -
Available on RxInterface<
Execute callback every time value changesT> , provided by the RxWorkerExtension extension -
onFirstChange(
WorkerCallback< T> callback) → Worker -
Available on RxInterface<
Execute callback only once when value changesT> , provided by the RxWorkerExtension extension -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggle(
) → void - Toggles the bool value between false and true
-
toggle(
) → void -
Available on Rx<
Toggles the bool value between false and truebool?> , provided by the RxnBoolExt extension -
toJson(
) → dynamic -
Returns the json representation of value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
T? v) → void -
Trigger a rebuild even if the value is the same
inherited
-
update(
T? fn(T? val)) → void -
Uses a callback to update value internally
inherited
Operators
-
operator %(
num other) → num -
operator &(
bool other) → bool -
operator &(
bool other) → bool? -
Available on Rx<
bool?> , provided by the RxnBoolExt extension -
operator *(
num other) → num -
operator +(
num other) → num -
operator -(
num other) → num -
operator /(
num other) → num -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator ^(
bool other) → bool -
operator |(
bool other) → bool -
operator |(
bool other) → bool? -
Available on Rx<
bool?> , provided by the RxnBoolExt extension