RxController class abstract

A base controller class for reactive state management using Rx variables.

Example:

class UserController extends RxController {
  final name = 'John'.obs;
  final age = 30.obs;
}
Mixed-in types

Constructors

RxController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Call this method to trigger onClose lifecycle event
inherited
init() → void
Call this method to trigger onInit lifecycle event
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
Called when the controller is about to be disposed
inherited
onInit() → void
Called immediately after the controller is created and before it starts being used
inherited
onReady() → void
Called after onInit when the controller and its state are ready
inherited
onStart() → void
Called when the controller is ready to start its work
inherited
ready() → void
Call this method to trigger onReady lifecycle event
inherited
start() → void
Call this method to trigger onStart lifecycle event
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited