FlowLifeCycleMixin mixin
Mixin that provides lifecycle callbacks for controllers
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Call this method to trigger onClose lifecycle event
-
init(
) → void - Call this method to trigger onInit lifecycle event
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void - Called when the controller is about to be disposed
-
onInit(
) → void - Called immediately after the controller is created and before it starts being used
-
onReady(
) → void - Called after onInit when the controller and its state are ready
-
onStart(
) → void - Called when the controller is ready to start its work
-
ready(
) → void - Call this method to trigger onReady lifecycle event
-
start(
) → void - Call this method to trigger onStart lifecycle event
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited