FlowPage class
A page definition for Flow routing
Constructors
- FlowPage({required String name, required Widget page(), TransitionType transition = TransitionType.none, String? title})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The route name
final
- page → Widget Function()
-
The page builder function
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional title for the route
final
- transition → TransitionType
-
Transition type
final
Methods
-
createPageRoute<
T> () → PageRoute< T> - Creates a route with transition animation
-
createRoute<
T> () → Route< T> - Creates a MaterialPageRoute for this page
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited