RxMap<K, V> class

A reactive Map that notifies listeners when modified

Inheritance
Implemented types

Constructors

RxMap(Map<K, V> initial)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
length int
The length of the map
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<K, V>
The current value stored in this notifier.
getter/setter pairinherited-setteroverride-getter

Methods

addAll(Map<K, V> entries) → void
Adds all entries to the map
addEntry(K key, V value) → void
Adds an entry to the map
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Removes all entries from the map
containsKey(K key) bool
Checks if map contains key
containsValue(V? value) bool
Checks if map contains value
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(K key) → V?
Removes an entry from the map
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](K key) → V?
Gets entry at key
operator []=(K key, V value) → void
Updates entry at key and notifies