Rxn<T> class

Nullable Rx class

Inheritance
Available extensions

Constructors

Rxn([T? initial])

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isFalse bool

Available on Rx<bool>, provided by the RxBoolExt extension

no setter
isFalse bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

no setter
isTrue bool

Available on Rx<bool>, provided by the RxBoolExt extension

no setter
isTrue bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T?
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
decrement([num by = 1]) → void

Available on Rx<num>, provided by the RxNumExt extension

dispose() → void
Discards any resources used by the object.
inherited
increment([num by = 1]) → void

Available on Rx<num>, provided by the RxNumExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onChanged(WorkerCallback<T> callback, {Duration? debounce}) Worker

Available on RxInterface<T>, provided by the RxWorkerExtension extension

Execute callback every time value changes
onFirstChange(WorkerCallback<T> callback) Worker

Available on RxInterface<T>, provided by the RxWorkerExtension extension

Execute callback only once when value changes
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void

Available on Rx<bool>, provided by the RxBoolExt extension

Toggles the bool value between false and true
toggle() → void

Available on Rx<bool?>, provided by the RxnBoolExt extension

Toggles the bool value between false and true
toJson() → dynamic
Returns the json representation of value.
inherited
toString() String
A string representation of this object.
inherited
trigger(T? v) → void
Trigger a rebuild even if the value is the same
inherited
update(T? fn(T? val)) → void
Uses a callback to update value internally
inherited

Operators

operator %(num other) num

Available on Rx<num>, provided by the RxNumExt extension

operator &(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

operator &(bool other) bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

operator *(num other) num

Available on Rx<num>, provided by the RxNumExt extension

operator +(num other) num

Available on Rx<num>, provided by the RxNumExt extension

operator -(num other) num

Available on Rx<num>, provided by the RxNumExt extension

operator /(num other) num

Available on Rx<num>, provided by the RxNumExt extension

operator ==(Object other) bool
The equality operator.
inherited
operator ^(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

operator |(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

operator |(bool other) bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension