RxnBool class
RxnBool for nullable boolean values
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
bool?> - Rx<
bool?> - RxnBool
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isFalse → bool
-
Available on Rx<
bool> , provided by the RxBoolExt extensionno setter - isFalse → bool?
-
Available on Rx<
bool?> , provided by the RxnBoolExt extensionno setter - isTrue → bool
-
Available on Rx<
bool> , provided by the RxBoolExt extensionno setter - isTrue → bool?
-
Available on Rx<
bool?> , provided by the RxnBoolExt extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ bool?
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggle(
) → void - Toggles the bool value between false and true
-
toggle(
) → void -
Available on Rx<
Toggles the bool value between false and truebool?> , provided by the RxnBoolExt extension -
toJson(
) → dynamic -
Returns the json representation of value.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
trigger(
bool? v) → void -
Trigger a rebuild even if the value is the same
inherited
-
update(
bool? fn(bool? val)) → void -
Uses a callback to update value internally
inherited
Operators
-
operator &(
bool other) → bool -
operator &(
bool other) → bool? -
Available on Rx<
bool?> , provided by the RxnBoolExt extension -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator ^(
bool other) → bool -
operator |(
bool other) → bool -
operator |(
bool other) → bool? -
Available on Rx<
bool?> , provided by the RxnBoolExt extension