rx/rx_workers library
Rx Workers - Workers for reactive operations
Classes
Extensions
-
RxWorkerExtension
on RxInterface<
T> - Extension on RxInterface for easier worker usage
Functions
-
debounce<
T> (RxInterface< T> observable, WorkerCallback<T> callback, {Duration time = const Duration(milliseconds: 500)}) → Worker -
Executes a callback after
delayof no changes (debounce). Similar to interval but sends the last value after user stops changing it. -
ever<
T> (RxInterface< T> observable, WorkerCallback<T> callback, {dynamic condition, Duration? debounce}) → Worker -
Executes a callback every time the value of
observablechanges. -
everAll<
T> (List< RxInterface< observables, WorkerCallback<T> >T> callback, {dynamic condition}) → Worker - Similar to ever, but takes a list of observables. The condition is common to all observables.
-
interval<
T> (RxInterface< T> observable, WorkerCallback<T> callback, {Duration delay = const Duration(seconds: 1), dynamic condition}) → Worker -
Executes a callback after
delayif the value ofobservabledoesn't change. -
once<
T> (RxInterface< T> observable, WorkerCallback<T> callback, {dynamic condition}) → Worker -
Executes a callback the first time the value of
observablechanges. -
workers(
) → Workers - Create workers container
Typedefs
-
WorkerCallback<
T> = void Function(T value)