ListNotifier class

Notifier that supports multiple listeners with optional IDs

Inheritance
Implementers

Constructors

ListNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) VoidCallback
Register a closure to be called when the object changes.
override
addListenerId(Object? id, VoidCallback listener) → void
Adds a listener with optional group id
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify({Object? id}) → void
Notifies all listeners or specific group
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() → void
Refresh all listeners
refreshGroup(Object id) → void
Refresh specific group
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
override
removeListenerId(Object? id, VoidCallback listener) → void
Removes a listener from group
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited